@@ -20,6 +20,7 @@
 
 #include <config.h>
 #include <gnome.h>
+#include <libgnomeui/gnome-window-icon.h>
 
 #include "io-gtk.h"
 #include "option.h"
@@ -29,11 +30,13 @@
 int
 main (int argc, char **argv)
 {
+  gnome_score_init("freecell");
+
   bindtextdomain (PACKAGE, GNOMELOCALEDIR);
   textdomain (PACKAGE);
 
   gnome_init("freecell", VERSION, argc, argv);
-
+  gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-cardgame.png");
   option_init();
   score_init();
 
