@@ -14,6 +14,7 @@
 #include <config.h>
 #include <gnome.h>
 #include <gdk_imlib.h>
+#include <libgnomeui/gnome-window-icon.h>
 
 #include "glines.h"
 
@@ -779,15 +780,15 @@ main (int argc, char *argv [])
 	GtkWidget *vbox, *hbox;
 	GnomeClient *client;
 	
+	gnome_score_init("glines");
+
 	srand(time(NULL));
 	
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
 
-	gnome_score_init("glines");
-
 	gnome_init ("glines", VERSION, argc, argv);
-
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/glines.xpm");
 	client = gnome_master_client ();
 
 	gtk_signal_connect (GTK_OBJECT (client), "save_yourself",  
