@@ -39,6 +39,7 @@ GnibblesProperties *gnibbles_properties_new ()
 	tmp->startlevel = gnome_config_get_int
 		("/gnibbles/Preferences/startlevel=1");
 	tmp->sound = gnome_config_get_int ("/gnibbles/Preferences/sound=1");
+  tmp->tilesize = gnome_config_get_int ("/gnibbles/Preferences/tilesize=10");
 
 	for (i = 0; i < NUMWORMS; i++) {
 		tmp->wormprops[i] = (GnibblesWormProps *) malloc (sizeof
@@ -92,6 +93,7 @@ GnibblesProperties *gnibbles_properties_copy (GnibblesProperties *props)
 	tmp->random = props->random;
 	tmp->startlevel = props->startlevel;
 	tmp->sound = props->sound;
+  tmp->tilesize = props->tilesize;
 	
 	for (i = 0; i < NUMWORMS; i++) {
 		tmp->wormprops[i] = (GnibblesWormProps *) malloc (sizeof
@@ -122,6 +124,7 @@ void gnibbles_properties_save (GnibblesProperties *props)
 	gnome_config_set_int ("/gnibbles/Preferences/startlevel",
 			props->startlevel);
 	gnome_config_set_int ("/gnibbles/Preferences/sound", props->sound);
+  gnome_config_set_int ("/gnibbles/Preferences/tilesize", props->tilesize);
 
 	for (i = 0; i < NUMWORMS; i++) {
 		sprintf (buffer, "/gnibbles/Worm%d/color", i);
